import 'dart:io';

import 'package:apus_drones_mobile/constants/UserType.dart';
import 'package:apus_drones_mobile/models/AuthLoginModel.dart';
import 'package:apus_drones_mobile/providers/AuthProvider.dart';
import 'package:apus_drones_mobile/screens/CreateUserScreen.dart';
import 'package:apus_drones_mobile/screens/PartnerOrdersScreen.dart';
import 'package:apus_drones_mobile/screens/PilotOrdersWaitingScreen.dart';
import 'package:apus_drones_mobile/screens/clients/ListOfPartners.dart';
import 'package:apus_drones_mobile/services/AuthService.dart';
import 'package:apus_drones_mobile/controllers/SnackbarController.dart';
import 'package:apus_drones_mobile/widgets/SignupChooseProfileDialog.dart';
import 'package:apus_drones_mobile/screens/AdminScreen.dart';
import 'package:flutter/material.dart';

class LoginScreen extends StatefulWidget {
  LoginScreen({Key? key}) : super(key: key);

  @override
  _LoginScreenState createState() => _LoginScreenState();
}

class _LoginScreenState extends State<LoginScreen> {
  AuthService service = AuthService();
  bool _passwordHidden = true;
  String email = '';
  String password = '';
  TextEditingController emailController = TextEditingController();
  TextEditingController passwordController = TextEditingController();
  SnackbarController snackbar = SnackbarController();
  final _formKey = GlobalKey<FormState>();

  @override
  void initState() {
    super.initState();
    AuthProvider().isAuthenticated().then((value) => value ? _goHome() : false);

    emailController.addListener(() {
      setState(() {
        email = emailController.text;
      });
    });

    passwordController.addListener(() {
      setState(() {
        password = passwordController.text;
      });
    });
  }

  Widget _getRoleHomeScreen(UserType role) {
    switch (role) {
      case UserType.CUSTOMER:
        return ListOfPartners();
      case UserType.PARTNER:
        return PartnerOrdersScreen();
      case UserType.ADMIN:
        return AdminScreen();
      case UserType.PILOT:
        return PilotOrdersWaitingScreen();
      // throw new Exception('Não há telas para o piloto ainda');
      default:
        throw new Exception('Tipo de usuário desconhecido');
    }
  }

  _doLogin() async {
    final login = AuthLoginModel(email: email, password: password);
    final result = await service.login(login);
    if (result['success']) {
      _goHome();
    } else {
      int? status = result['status'];
      if (status == HttpStatus.forbidden) {
        snackbar.open("Usuário ou senha incorretos.", context);
      }
    }
  }

  _goHome() {
    AuthProvider().getTokenData().then(
          (tokenData) => Navigator.pushReplacement(
            context,
            MaterialPageRoute(
              builder: (context) => _getRoleHomeScreen(tokenData['role']),
            ),
          ),
        );
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      resizeToAvoidBottomInset: false,
      body: Container(
        padding: const EdgeInsets.only(top: 70, right: 25, left: 25),
        decoration: BoxDecoration(
          color: Theme.of(context).primaryColor,
        ),
        child: Form(
          key: _formKey,
          child: Column(
            // mainAxisAlignment: MainAxisAlignment.center,
            // crossAxisAlignment: CrossAxisAlignment.center,
            children: [
              Row(
                children: [
                  Image.asset(
                    'lib/assets/img/logo.png',
                    width: MediaQuery.of(context).size.width * 0.4,
                  ),
                  Expanded(
                    child: Text(
                      'APUS DRONES',
                      textAlign: TextAlign.center,
                      style: TextStyle(
                          color: Theme.of(context).canvasColor,
                          // fontWeight: FontWeight.bold,
                          fontSize: 32,
                          fontWeight: FontWeight.w600),
                    ),
                  ),
                ],
              ),
              SizedBox(height: 60),
              TextFormField(
                controller: emailController,
                validator: (value) {
                  if (value == null ||
                      value.isEmpty ||
                      !RegExp("[a-z0-9!#\$%&'*+/=?^_`{|}~-]+(?:\.[a-z0-9!#\$%&'*+/=?^_`{|}~-]+)*@(?:[a-z0-9](?:[a-z0-9-]*[a-z0-9])?\.)+[a-z0-9](?:[a-z0-9-]*[a-z0-9])?")
                          .hasMatch(value)) {
                    return 'E-mail inválido';
                  }
                  return null;
                },
                decoration: InputDecoration(
                  hintText: 'E-mail',
                  border: OutlineInputBorder(),
                  fillColor: Theme.of(context).canvasColor,
                  filled: true,
                  errorStyle: TextStyle(color: Theme.of(context).canvasColor),
                ),
              ),
              SizedBox(height: 30),
              TextFormField(
                controller: passwordController,
                validator: (value) {
                  if (value == null || value.isEmpty)
                    return 'Entre com uma senha';
                  return null;
                },
                obscureText: _passwordHidden,
                decoration: InputDecoration(
                  hintText: 'Senha',
                  border: OutlineInputBorder(),
                  fillColor: Theme.of(context).canvasColor,
                  filled: true,
                  errorStyle: TextStyle(color: Theme.of(context).canvasColor),
                  suffixIcon: IconButton(
                    icon: Icon(
                      _passwordHidden ? Icons.visibility_off : Icons.visibility,
                    ),
                    onPressed: () {
                      setState(() {
                        _passwordHidden = !_passwordHidden;
                      });
                    },
                  ),
                ),
              ),
              SizedBox(height: 30),
              // Text(
              //   'Ainda não tem uma conta?',
              //   style: TextStyle(
              //     color: Theme.of(context).canvasColor,
              //     fontSize: 16,
              //   ),
              // ),
              TextButton(
                onPressed: () {
                  showDialog(
                    context: context,
                    builder: (context) => SignupChooseProfileDialog(
                      options: {
                        'Sou cliente': MaterialPageRoute(
                          builder: (context) => CreateUserScreen(
                            role: UserType.CUSTOMER,
                          ),
                        ),
                        'Sou parceiro': MaterialPageRoute(
                          builder: (context) => CreateUserScreen(
                            role: UserType.PARTNER,
                          ),
                        ),
                      },
                    ),
                  );
                },
                style: TextButton.styleFrom(
                  primary: Theme.of(context).canvasColor,
                  textStyle: TextStyle(
                    color: Theme.of(context).canvasColor,
                    fontSize: 16,
                    // fontStyle: FontStyle.italic,
                  ),
                ),
                child: Text(
                  'Ainda não tem uma conta?\nCadastre-se aqui',
                  textAlign: TextAlign.center,
                ),
              ),
              SizedBox(height: 30),
              ElevatedButton(
                onPressed: () {
                  if (_formKey.currentState!.validate()) {
                    _doLogin();
                  }
                },
                style: ElevatedButton.styleFrom(
                  primary: Colors.white,
                  padding: EdgeInsets.symmetric(horizontal: 50),
                ),
                child: Text(
                  'ENTRAR',
                  style: TextStyle(color: Theme.of(context).primaryColor),
                ),
              )
            ],
          ),
        ),
      ),
    );
  }
}
