import 'package:apus_drones_mobile/constants/PartnerStatusEnum.dart';
import 'package:apus_drones_mobile/constants/UserType.dart';
import 'package:apus_drones_mobile/models/OrderModel.dart';
import 'package:apus_drones_mobile/models/PartnerModel.dart';
import 'package:apus_drones_mobile/models/PartnerStatus.dart';
import 'package:apus_drones_mobile/services/PartnerService.dart';
import 'package:apus_drones_mobile/widgets/BotNavBar.dart';
import 'package:apus_drones_mobile/widgets/Fee.dart';
import 'package:apus_drones_mobile/widgets/PartnerOrderDetailsHeader.dart';
import 'package:apus_drones_mobile/widgets/StatusButton.dart';
import 'package:flutter/material.dart';

import 'Appbar.dart';

class PartnerDetailScreen extends StatefulWidget {
  final PartnerModel partner;
  const PartnerDetailScreen(this.partner);

  @override
  _PartnerDetailScreenState createState() => _PartnerDetailScreenState();
}

class _PartnerDetailScreenState extends State<PartnerDetailScreen> {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
        appBar: Appbar(title: 'Detalhes do parceiro'),
        bottomNavigationBar: BotNavBar(role: UserType.PARTNER),
        body: BodyCriarCliente());
  }

  Widget BodyCriarCliente() {
    return Container(
      height: MediaQuery.of(context).size.height * 0.9,
      child: Center(
        child: Column(children: [
          Padding(
            padding: EdgeInsets.all(20),
            child: Container(
              width: 140.0,
              height: 140.0,
              decoration: BoxDecoration(
                shape: BoxShape.circle,
                border: Border.all(color: Colors.black26),
                image: DecorationImage(
                    fit: BoxFit.fill,
                    image: NetworkImage(widget.partner.avatarUrl)),
              ),
            ),
          ),
          Padding(
            padding: EdgeInsets.fromLTRB(0, 0, 0, 20),
            child: Text(
              "${widget.partner.name}",
              style: TextStyle(fontSize: 24, fontWeight: FontWeight.bold),
            ),
          ),
          Expanded(
              child: SingleChildScrollView(
            child: getColumn(),
          )),
          showButtons(),
          ElevatedButton(
              onPressed: () => {Navigator.pop(context)},
              child: Text(
                "Voltar",
                style: TextStyle(fontSize: 20),
              ),
              style: ElevatedButton.styleFrom(
                  primary: Colors.purple, minimumSize: Size(92, 36)))
        ]),
      ),
    );
  }

  Column getColumn() {
    List<Widget> list = [];
    list.add(Padding(
      padding: EdgeInsets.fromLTRB(0, 0, 0, 10),
      child: Text('Email: ${widget.partner.email}',
          style: TextStyle(fontSize: 16)),
    ));
    list.add(Padding(
      padding: EdgeInsets.fromLTRB(0, 0, 0, 10),
      child: Text('CPF/CNPJ: ${widget.partner.cpfCnpj}',
          style: TextStyle(fontSize: 16)),
    ));
    list.add(Padding(
      padding: EdgeInsets.fromLTRB(0, 0, 0, 10),
      child: Text('Endereço: ${widget.partner.addresses}',
          style: TextStyle(fontSize: 16)),
    ));
    list.add(Padding(
      padding: EdgeInsets.fromLTRB(0, 0, 0, 10),
      child: Text('Status: ${widget.partner.status?.label}',
          style: TextStyle(fontSize: 16)),
    ));
    /*
   final String? cpfCnpj;
  final List<AddressModel>? addresses;
*/
    return new Column(children: list);
  }

  Row showButtons() {
    if (widget.partner.status == PartnerStatusEnum.PENDING) {
      return Row(
        children: [
          Padding(
            padding: EdgeInsets.fromLTRB(100, 0, 0, 20),
          ),
          ElevatedButton(
              onPressed: () => {changeStatus(false)},
              child: Text(
                "Rejeitar",
                style: TextStyle(fontSize: 20),
              ),
              style: ElevatedButton.styleFrom(
                  primary: Colors.red, minimumSize: Size(92, 36))),
          Padding(
            padding: EdgeInsets.fromLTRB(10, 0, 0, 20),
          ),
          ElevatedButton(
              onPressed: () => {changeStatus(true)},
              child: Text(
                "Aceitar",
                style: TextStyle(fontSize: 20),
              ),
              style: ElevatedButton.styleFrom(
                  primary: Colors.blue, minimumSize: Size(92, 36)))
        ],
      );
    } else if (widget.partner.status == PartnerStatusEnum.REJECTED) {
      return Row(
        children: [
          Padding(
            padding: EdgeInsets.fromLTRB(100, 0, 0, 20),
          ),
          Padding(
            padding: EdgeInsets.fromLTRB(57, 0, 0, 20),
          ),
          ElevatedButton(
              onPressed: () => {changeStatus(true)},
              child: Text(
                "Aceitar",
                style: TextStyle(fontSize: 20),
              ),
              style: ElevatedButton.styleFrom(
                  primary: Colors.blue, minimumSize: Size(92, 36)))
        ],
      );
    } else {
      return Row(
        children: [
          Padding(
            padding: EdgeInsets.fromLTRB(154, 0, 0, 20),
          ),
          ElevatedButton(
              onPressed: () => {changeStatus(false)},
              child: Text(
                "Rejeitar",
                style: TextStyle(fontSize: 20),
              ),
              style: ElevatedButton.styleFrom(
                  primary: Colors.red, minimumSize: Size(92, 36))),
        ],
      );
    }
  }

  changeStatus(bool status) async {
    if (status) {
      await PartnerService()
          .patchPartnerStatus(PartnerStatus(true), widget.partner.id);
    } else {
      await PartnerService()
          .patchPartnerStatus(PartnerStatus(false), widget.partner.id);
    }
    Navigator.pop(context);
  }
}
