import 'package:apus_drones_mobile/constants/Constants.dart';
import 'package:apus_drones_mobile/models/PartnerModel.dart';
import 'package:apus_drones_mobile/services/PartnerService.dart';
import 'package:apus_drones_mobile/services/ProfileService.dart';
import 'package:flutter/material.dart';

class PartnerEditProfileScreen extends StatefulWidget {
  final PartnerModel? partner;
  PartnerEditProfileScreen({Key? key, required this.partner}) : super(key: key);

  @override
  _PartnerEditProfileScreenState createState() =>
      _PartnerEditProfileScreenState();
}

class _PartnerEditProfileScreenState extends State<PartnerEditProfileScreen> {
  TextEditingController nameController = TextEditingController();
  TextEditingController cpfController = TextEditingController();
  TextEditingController passwordController = TextEditingController();
  TextEditingController emailController = TextEditingController();
  // TextEditingController cepController = TextEditingController();
  // TextEditingController addressController = TextEditingController();

  late bool passwordVisibility;

  //Partner
  PartnerModel? _partner;

  PartnerService partnerService = PartnerService();
  ProfileService profileService = ProfileService();

  @override
  void initState() {
    super.initState();

    final _currentPartner = widget.partner;

    this.setState(() {
      _partner = _currentPartner;
      if (_currentPartner != null) {
        nameController.value = TextEditingValue(text: _currentPartner.name);
        cpfController.value =
            TextEditingValue(text: _currentPartner.cpfCnpj ?? '');
        emailController.value =
            TextEditingValue(text: _currentPartner.email ?? '');
        // addressController.value = TextEditingValue(
        //     text: _currentPartner.addresses?[0].toString() ?? '');
        // cepController.value =
        //     TextEditingValue(text: _currentPartner.addresses?[0].zipCode ?? '');
      }
      passwordVisibility = false;
    });
  }

  void updatePartner() async {
    final _currentPartner = _partner;
    if (_currentPartner == null) {
      return;
    }

    PartnerModel newPartner = PartnerModel(
        id: _currentPartner.id,
        name: nameController.text,
        email: emailController.text,
        cpfCnpj: cpfController.text,
        avatarUrl: _currentPartner.avatarUrl,
        status: _currentPartner.status);

    try {
      await profileService.updatePartnerProfile(newPartner);
      Navigator.pop(context);
    } catch (error) {
      print(error);
    }
  }

  void updateCustomerProfilePhoto() {
    //customer?.avatarUrl =
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        leading: IconButton(
            onPressed: () async {
              Navigator.of(context).pushNamed('LoginScreen');
            },
            icon: Icon(
              Icons.arrow_back_rounded,
              color: Colors.black,
              size: 24,
            )),
        title: Text('Editar Perfil'),
      ),
      body: SingleChildScrollView(
        child: GestureDetector(
          onTap: () {
            FocusScope.of(context).unfocus();
          },
          child: Padding(
            padding: EdgeInsets.only(top: 15),
            child: Column(
              children: [
                fotoPerfil(),
                Column(
                  mainAxisSize: MainAxisSize.max,
                  children: [
                    inputUsuarioTxt(
                        "Nome", "Ex: João da Silva", nameController),
                    inputUsuarioNumber(
                        "CPF", "Ex: 123.456.789-00", cpfController),
                    inputUsuarioTxt(
                        "Email", "Ex: exemplo@gmail.com", emailController),
                    // inputUsuarioTxt("Endereço", "Ex: Rua Assis Brasil, 123",
                    //     addressController),
                    // inputUsuarioNumber("CEP", "Ex: 12345-678", cepController),
                    inputUsuarioSenha("Senha", passwordController),
                    botoesRodape(),
                  ],
                )
              ],
            ),
          ),
        ),
      ),
    );
  }

  fotoPerfil() {
    return Center(
      child: Stack(
        children: [
          Container(
            width: 130,
            height: 130,
            decoration: BoxDecoration(
              border: Border.all(
                  width: 4, color: Theme.of(context).scaffoldBackgroundColor),
              boxShadow: [
                BoxShadow(
                  spreadRadius: 2,
                  blurRadius: 8,
                  color: Colors.black.withOpacity(0.1),
                )
              ],
              shape: BoxShape.circle,
              image: DecorationImage(
                image: NetworkImage(_partner?.avatarUrl ?? IMG_NO_PHOTO),
              ),
            ),
          ),
          Positioned(
            bottom: 0,
            right: 0,
            child: Container(
              height: 40,
              width: 40,
              decoration: BoxDecoration(
                  color: Colors.red,
                  shape: BoxShape.circle,
                  border: Border.all(
                      width: 4,
                      color: Theme.of(context).scaffoldBackgroundColor)),
              child: IconButton(
                padding: EdgeInsets.all(0),
                onPressed: () {
                  print('Button Pressed');
                  //Se usuário logado for cliente
                  updateCustomerProfilePhoto();

                  //Se usuário logado for parceiro
                  //updatePartnerProfilePhoto();
                },
                icon: Icon(
                  Icons.edit,
                  color: Colors.white,
                ),
              ),
            ),
          )
        ],
      ),
    );
  }

  inputUsuarioTxt(
      String labelText, String hintText, TextEditingController controller) {
    return Padding(
      padding: EdgeInsets.only(left: 20, top: 25, right: 20, bottom: 0),
      child: TextFormField(
        controller: controller,
        obscureText: false,
        decoration: InputDecoration(
          labelText: labelText,
          labelStyle: TextStyle(
            fontFamily: 'Poppins',
          ),
          hintText: hintText,
          hintStyle: TextStyle(
            fontFamily: 'Poppins',
          ),
          enabledBorder: OutlineInputBorder(
            borderSide: BorderSide(
              color: Color(0x00000000),
              width: 1,
            ),
            borderRadius: BorderRadius.circular(10),
          ),
          focusedBorder: OutlineInputBorder(
            borderSide: BorderSide(
              color: Color(0x00000000),
              width: 1,
            ),
            borderRadius: BorderRadius.circular(10),
          ),
          filled: true,
        ),
        style: TextStyle(
          fontFamily: 'Poppins',
        ),
        keyboardType: TextInputType.name,
      ),
    );
  }

  inputUsuarioNumber(
      String labelText, String hintText, TextEditingController controller) {
    return Padding(
      padding: EdgeInsets.only(left: 20, top: 25, right: 20, bottom: 0),
      child: TextFormField(
        controller: controller,
        obscureText: false,
        decoration: InputDecoration(
          labelText: labelText,
          labelStyle: TextStyle(
            fontFamily: 'Poppins',
          ),
          hintText: hintText,
          hintStyle: TextStyle(
            fontFamily: 'Poppins',
          ),
          enabledBorder: OutlineInputBorder(
            borderSide: BorderSide(
              color: Color(0x00000000),
              width: 1,
            ),
            borderRadius: BorderRadius.circular(10),
          ),
          focusedBorder: OutlineInputBorder(
            borderSide: BorderSide(
              color: Color(0x00000000),
              width: 1,
            ),
            borderRadius: BorderRadius.circular(10),
          ),
          filled: true,
        ),
        style: TextStyle(
          fontFamily: 'Poppins',
        ),
        keyboardType: TextInputType.number,
      ),
    );
  }

  inputUsuarioSenha(String labelText, TextEditingController controller) {
    return Padding(
      padding: EdgeInsetsDirectional.fromSTEB(20, 15, 20, 0),
      child: TextFormField(
        controller: controller,
        obscureText: !passwordVisibility,
        decoration: InputDecoration(
          labelText: labelText,
          labelStyle: TextStyle(
            fontFamily: 'Poppins',
          ),
          enabledBorder: UnderlineInputBorder(
            borderSide: BorderSide(
              color: Color(0x00000000),
              width: 1,
            ),
            borderRadius: BorderRadius.circular(10),
          ),
          focusedBorder: UnderlineInputBorder(
            borderSide: BorderSide(
              color: Color(0x00000000),
              width: 1,
            ),
            borderRadius: BorderRadius.circular(10),
          ),
          filled: true,
          suffixIcon: InkWell(
            onTap: () => setState(
              () => passwordVisibility = !passwordVisibility,
            ),
            child: Icon(
              passwordVisibility
                  ? Icons.visibility_outlined
                  : Icons.visibility_off_outlined,
              color: Color(0xFF757575),
              size: 22,
            ),
          ),
        ),
        style: TextStyle(
          fontFamily: 'Poppins',
        ),
        keyboardType: TextInputType.visiblePassword,
      ),
    );
  }

  botoesRodape() {
    return Padding(
      padding: EdgeInsets.only(top: 50),
      child: Row(mainAxisAlignment: MainAxisAlignment.spaceAround, children: [
        ElevatedButton(
          onPressed: () {
            print('Button pressed ...');
            Navigator.pop(context);
          },
          child: Text(
            'CANCELAR',
            style: TextStyle(
              fontFamily: 'Poppins',
              color: Color(0xFFFB0808),
              fontSize: 15,
              fontWeight: FontWeight.w500,
            ),
          ),
          style: ElevatedButton.styleFrom(
            primary: Colors.white,
            fixedSize: Size(150, 40),
            elevation: 3,
            shape:
                RoundedRectangleBorder(borderRadius: BorderRadius.circular(20)),
          ),
        ),
        ElevatedButton(
          onPressed: () {
            print('Button pressed ...');
            updatePartner();
          },
          child: Text(
            'SALVAR',
            style: TextStyle(
              fontFamily: 'Poppins',
              color: Colors.white,
              fontSize: 15,
              fontWeight: FontWeight.w500,
            ),
          ),
          style: ElevatedButton.styleFrom(
            primary: Color(0xFFFB0808),
            fixedSize: Size(150, 40),
            elevation: 3,
            shape:
                RoundedRectangleBorder(borderRadius: BorderRadius.circular(20)),
          ),
        ),
      ]),
    );
  }
}
