import 'package:apus_drones_mobile/constants/UserType.dart';
import 'package:apus_drones_mobile/providers/ActiveBarItemProvider.dart';
import 'package:apus_drones_mobile/providers/AuthProvider.dart';
import 'package:apus_drones_mobile/screens/CartScreen.dart';
import 'package:apus_drones_mobile/screens/LoginScreen.dart';
import 'package:apus_drones_mobile/screens/OrdersScreen.dart';
import 'package:apus_drones_mobile/screens/PartnerOrdersScreen.dart';
import 'package:apus_drones_mobile/screens/PartnerProductListScreen.dart';
import 'package:apus_drones_mobile/screens/PilotOrdersWaitingScreen.dart';
import 'package:apus_drones_mobile/screens/PilotTripsScreen.dart';
import 'package:apus_drones_mobile/screens/clients/ListOfPartners.dart';
import 'package:apus_drones_mobile/utils/getRoleProfileScreen.dart';
import 'package:apus_drones_mobile/widgets/ProfileModal.dart';
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

class BotNavBar extends StatefulWidget {
  final UserType role;
  const BotNavBar({Key? key, required this.role}) : super(key: key);

  @override
  _BotNavBarState createState() => _BotNavBarState();
}

class _BotNavBarState extends State<BotNavBar> {
  BottomNavigationBar _buildCustomerBotNavBar(BuildContext context) {
    return BottomNavigationBar(
      type: BottomNavigationBarType.fixed,
      onTap: (index) {
        if (index == 0) {
          return this.showMenu();
        }
        if (index ==
            Provider.of<ActiveBarItemProvider>(context, listen: false)
                .activeIndex) {
          return;
        }

        Provider.of<ActiveBarItemProvider>(context, listen: false)
            .setActiveIndex(index);

        var routes = {
          UserType.CUSTOMER: [
            null,
            ListOfPartners.routeName,
            CartScreen.routeName,
            OrdersScreen.routeName,
          ],
          UserType.PARTNER: [
            null,
            null,
            PartnerProductListScreen.routeName,
            PartnerOrdersScreen.routeName
          ],
          UserType.PILOT: [
            null,
            PilotOrdersWaitingScreen.routeName,
            PilotTripsScreen.routeName
          ],
          UserType.ADMIN: []
        };

        if (routes[widget.role]![index] != null) {
          Navigator.of(context).pushNamed(routes[widget.role]![index]);
        }
      },
      items: _getBottomNavigationItems(widget.role),
      currentIndex: Provider.of<ActiveBarItemProvider>(context).activeIndex,
    );
  }

  void _logout() async {
    final authProvider = Provider.of<AuthProvider>(context, listen: false);
    await authProvider.logout();
    Navigator.pushAndRemoveUntil(
        context,
        MaterialPageRoute(
          builder: (context) => LoginScreen(),
        ),
        (route) => false);
  }

  void _goToProfile() async {
    final tokenData = await AuthProvider().getTokenData();
    Widget screen = getRoleProfileScreen(tokenData["role"]);
    Navigator.push(context, MaterialPageRoute(builder: (context) => screen));
  }

  int _getIdUser(role) {
    return role == UserType.CUSTOMER ? 1 : 3;
  }

  @override
  Widget build(BuildContext context) {
    return _buildCustomerBotNavBar(context);
  }

  showMenu() async {
    final tokenData = await AuthProvider().getTokenData();

    var menuItems = <ProfileMenuItem>[];
    if (widget.role != UserType.ADMIN) {
      menuItems.add(
        ProfileMenuItem(
          icon: Icons.account_circle,
          title: "Meu Perfil",
          onMenuClicked: () {
            _goToProfile();
            print('Meu perfil clicado');
          },
        ),
      );
    }
    menuItems.add(
      ProfileMenuItem(
        icon: Icons.logout,
        title: "Sair",
        onMenuClicked: () {
          _logout();
        },
      ),
    );

    showModalBottomSheet(
      context: context,
      builder: (_) => ProfileModal(
        idUser: _getIdUser(tokenData["role"]),
        items: menuItems,
      ),
    );
  }
}

List<BottomNavigationBarItem> _getBottomNavigationItems(UserType role) {
  var items = {
    UserType.CUSTOMER: [
      BottomNavigationBarItem(icon: Icon(Icons.menu), label: "Menu"),
      BottomNavigationBarItem(icon: Icon(Icons.home), label: 'Início'),
      BottomNavigationBarItem(
          icon: Icon(Icons.shopping_cart), label: 'Carrinho'),
      BottomNavigationBarItem(
          icon: Icon(Icons.request_quote), label: 'Meus pedidos')
    ],
    UserType.PARTNER: [
      BottomNavigationBarItem(icon: Icon(Icons.menu), label: "Menu"),
      BottomNavigationBarItem(icon: Icon(Icons.home), label: 'Início'),
      BottomNavigationBarItem(icon: Icon(Icons.article), label: 'Produtos'),
      BottomNavigationBarItem(icon: Icon(Icons.request_quote), label: 'Pedidos')
    ],
    UserType.PILOT: [
      BottomNavigationBarItem(icon: Icon(Icons.menu), label: "Menu"),
      BottomNavigationBarItem(
          icon: Icon(Icons.request_quote), label: 'Pedidos'),
      BottomNavigationBarItem(icon: Icon(Icons.flight), label: 'Vôos'),
    ],
    UserType.ADMIN: [
      BottomNavigationBarItem(icon: Icon(Icons.menu), label: "Menu"),
      BottomNavigationBarItem(icon: Icon(Icons.home), label: "Início"),
    ]
  };

  return (items[role] ?? []).toList();
}
